summaryrefslogtreecommitdiff
path: root/src/include
diff options
context:
space:
mode:
authorChristian Grothoff <christian@grothoff.org>2020-01-12 23:13:46 +0100
committerChristian Grothoff <christian@grothoff.org>2020-01-12 23:13:46 +0100
commit6b0c121fc9818b4cce00bf4540c53cb79d968766 (patch)
tree79426109ec72094c0344e5b8d2112f6fad5bd817 /src/include
parent27911aaa17ed6341924e88b3cc2e9a40e23e539c (diff)
downloadexchange-6b0c121fc9818b4cce00bf4540c53cb79d968766.tar.gz
exchange-6b0c121fc9818b4cce00bf4540c53cb79d968766.tar.bz2
exchange-6b0c121fc9818b4cce00bf4540c53cb79d968766.zip
clean up string traits"
Diffstat (limited to 'src/include')
-rw-r--r--src/include/taler_testing_lib.h70
1 files changed, 19 insertions, 51 deletions
diff --git a/src/include/taler_testing_lib.h b/src/include/taler_testing_lib.h
index bb5270042..aa3b537d7 100644
--- a/src/include/taler_testing_lib.h
+++ b/src/include/taler_testing_lib.h
@@ -2055,36 +2055,35 @@ TALER_TESTING_make_trait_wtid (unsigned int index,
/**
- * Offer amount in a trait.
+ * Offer HTTP url in a trait.
*
- * @param index which amount is to be offered,
+ * @param index which url is to be picked,
* in case multiple are offered.
- * @param amount the amount to offer.
+ * @param url the url to offer.
* @return the trait.
*/
struct TALER_TESTING_Trait
-TALER_TESTING_make_trait_amount (unsigned int index,
- const char *amount);
+TALER_TESTING_make_trait_url (unsigned int index,
+ const char *url);
/**
- * Obtain an amount from @a cmd.
+ * Obtain a HTTP url from @a cmd.
*
- * @param cmd command to extract the amount from.
- * @param index which amount is to be picked, in case
+ * @param cmd command to extract the url from.
+ * @param index which url is to be picked, in case
* multiple are offered.
- * @param amount[out] where to write the wire details.
- *
+ * @param url[out] where to write the url.
* @return #GNUNET_OK on success.
*/
int
-TALER_TESTING_get_trait_amount (const struct TALER_TESTING_Command *cmd,
- unsigned int index,
- const char **amount);
+TALER_TESTING_get_trait_url (const struct TALER_TESTING_Command *cmd,
+ unsigned int index,
+ const char **url);
/**
* Offer url in a trait.
*
* @param index which url is to be picked,
* in case multiple are offered.
@@ -2092,12 +2091,12 @@ TALER_TESTING_get_trait_amount (const struct TALER_TESTING_Command *cmd,
* @return the trait.
*/
struct TALER_TESTING_Trait
-TALER_TESTING_make_trait_url (unsigned int index,
- const char *url);
+TALER_TESTING_make_trait_payto (unsigned int index,
+ const char *url);
/**
* Obtain a url from @a cmd.
*
* @param cmd command to extract the url from.
* @param index which url is to be picked, in case
@@ -2106,9 +2105,9 @@ TALER_TESTING_make_trait_url (unsigned int index,
* @return #GNUNET_OK on success.
*/
int
-TALER_TESTING_get_trait_url (const struct TALER_TESTING_Command *cmd,
- unsigned int index,
- const char **url);
+TALER_TESTING_get_trait_payto (const struct TALER_TESTING_Command *cmd,
+ unsigned int index,
+ const char **url);
/**
@@ -2170,37 +2169,6 @@ TALER_TESTING_make_trait_amount_obj (unsigned int index,
/**
- * Offer a "reject" CMD reference.
- *
- * @param index which reference is to be offered,
- * in case multiple are offered.
- * @param rejected_reference the reference to offer.
- *
- * @return the trait.
- */
-struct TALER_TESTING_Trait
-TALER_TESTING_make_trait_rejected (unsigned int index,
- const char *rejected);
-
-
-/**
- * Obtain the reference to a "reject" CMD. Usually offered
- * by _rejected_ bank transfers.
- *
- * @param cmd command to extract the reference from.
- * @param index which reference is to be picked, in case
- * multiple are offered.
- * @param rejected_reference[out] where to write the reference.
- *
- * @return #GNUNET_OK on success.
- */
-int
-TALER_TESTING_get_trait_rejected (const struct TALER_TESTING_Command *cmd,
- unsigned int index,
- const char **rejected_reference);
-
-
-/**
* Offer a command in a trait.
*
* @param index always zero. Commands offering this
@@ -2055,36 +2055,35 @@ TALER_TESTING_make_trait_wtid (unsigned int index,
/**
- * Offer url in a trait.
+ * Offer PAYTO url in a trait.
*
* @param index which url is to be picked,
@@ -2092,12 +2091,12 @@ TALER_TESTING_get_trait_amount (const struct TALER_TESTING_Command *cmd,
/**
- * Obtain a url from @a cmd.
+ * Obtain a PAYTO url from @a cmd.
*
* @param cmd command to extract the url from.